Work order

Client: | Juca | Sale #: | 23456
Sales Person: | SalesPerson | Open Date: | 01/01/12

Item | WO | Price | Total
1 x Description (Missing: 1) | A | $10.00 | $10.00
|  | Total: | $10.00

WO | Estimated finish
A | 01/01/13
B | 01/09/13

Method | Value
Money | 10.00

Sales Person: | SalesPerson
Client: | Juca Address:

Code | Item | Qty
| Description | 1

Sale: | 23456
Date: | 01/01/12 | Deliver: | 01/01/13
Desc: | A

Longe | Esf | Cil | Eixo | DNP | Alt | Prisma
OD: | 0.00 | 0.00 | 0.00 | 0.00 | 0.00 | 0.00
OE: | 0.00 | 0.00 | 0.00 | 0.00 | 0.00 | 0.00

Perto | Esf | Cil | Eixo | DNP | Adição
OD: | 0.00 | 0.00 | 0.00 | 0.00 | 0.00
OE: | 0.00 | 0.00 | 0.00 | 0.00 | 0.00

Client signature

Sales Person: | SalesPerson
Client: | Juca Address:

Code | Item | Qty

Sale: | 23456
Date: | 01/01/12 | Deliver: | 01/09/13
Desc: | B

Longe | Esf | Cil | Eixo | DNP | Alt | Prisma
OD: | 0.00 | 0.00 | 0.00 | 0.00 | 0.00 | 0.00
OE: | 0.00 | 0.00 | 0.00 | 0.00 | 0.00 | 0.00

Perto | Esf | Cil | Eixo | DNP | Adição
OD: | 0.00 | 0.00 | 0.00 | 0.00 | 0.00
OE: | 0.00 | 0.00 | 0.00 | 0.00 | 0.00

Client signature